moralis-streams-client
======================

OpenAPI client module for moralis streams API

![Image](https://img.shields.io/github/license/rstms/moralis_streams_client)

![Image](https://img.shields.io/pypi/v/moralis_streams_client.svg)


![Image](https://circleci.com/gh/rstms/moralis_streams_client/tree/master.svg?style=shield)

![Image](https://readthedocs.org/projects/moralis-streams-client/badge/?version=latest)

![Image](https://pyup.io/repos/github/rstms/moralis_streams_client/shield.svg)

Client module and CLI for the Moralis Streams API


* Free software: MIT license
* Documentation: https://moralis-streams-client.readthedocs.io.



Credits
-------

This package was created with Cookiecutter and `rstms/cookiecutter-python-cli`, a fork of the `audreyr/cookiecutter-pypackage` project template.

[audreyr/cookiecutter](https://github.com/audreyr/cookiecutter)
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
[rstms/cookiecutter-python-cli](https://github.com/rstms/cookiecutter-python-cli)
